@@ -10,14 +10,14 @@ from .utils import Interactor, pastecode, pastevar
 from .version import version
 
 
-def interact(**kwargs):
+def interact(prompt=">>>", **kwargs):
     glb = sys._getframe(1).f_globals
     mname = glb["__name__"]
     module = importlib.import_module(mname)
     lcl = sys._getframe(1).f_locals
     if not (sess := current_session()):
         sess = serve(**kwargs, template={"title": mname})
-    Evaluator(module, glb, lcl, sess).loop()
+    Evaluator(module, glb, lcl, sess, prompt=prompt).loop()
 
 
 def debug(**kwargs):
