@@ -71,7 +71,7 @@ class PopupNav {
                 ret.push(entry);
             }
         }
-        return ret;
+        return ret.reverse();
     }
 
     submit() {
@@ -196,7 +196,6 @@ class Repl {
                 name: "history",
                 anchor: this.inputOuter,
                 onselect: entries => {
-                    console.log(entries);
                     this.editor.setValue(entries.map(x => x.text).join("\n"));
                     const nlines = this.editor.getModel().getLineCount();
                     this.editor.setPosition({lineNumber: nlines, column: 1000000});
@@ -804,10 +803,13 @@ class Repl {
     }
 
     recv_set_nav(data) {
-        this.nav.innerHTML = "";
-        if (data.value) {
-            let elem = this.reify(data.value);
-            this.nav.appendChild(elem);
+        if (data.navid === undefined || data.navid !== this.last_nav) {
+            this.nav.innerHTML = "";
+            if (data.value) {
+                let elem = this.reify(data.value);
+                this.nav.appendChild(elem);
+            }
+            this.last_nav = data.navid;
         }
     }
 
